# Vizro

[![Python version](https://img.shields.io/badge/python-3.8%20%7C%203.9%20%7C%203.10%20%7C%203.11-blue.svg)]()
[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)]()

Vizro is a toolkit for creating modular data visualisation applications

## Documentation

See the [`docs`](https://vizro.readthedocs.io/en/latest/) for more details

## Contributors

See the [authors](https://github.com/mckinsey/vizro/blob/main/vizro-core/docs/pages/development/authors.md) file for more details

## License

`vizro` is distributed under the terms of the [Apache License 2.0](https://www.apache.org/licenses/LICENSE-2.0)
